<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://etracker.com
 * @since             1.0.0
 * @package           Etracker
 *
 * @wordpress-plugin
 * Plugin Name:       etracker Analytics
 * Plugin URI:        https://wordpress.org/plugins/etracker
 * Description:       Official etracker Analytics plugin for WordPress.
 * Version:           1.8.4
 * Author:            etracker GmbH
 * Author URI:        https://etracker.com/?etcc_cmp=eA%20Plugin&etcc_med=Pluginstore&etcc_grp=wordpress&etcc_ctv=pluginheader
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       etracker
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'ETRACKER_VERSION', '1.8.4' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-etracker-activator.php
 */
function etracker_activate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-etracker-activator.php';
	Etracker_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-etracker-deactivator.php
 */
function etracker_deactivate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-etracker-deactivator.php';
	Etracker_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'etracker_activate' );
register_deactivation_hook( __FILE__, 'etracker_deactivate' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-etracker.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function etracker_run() {
	$plugin = new Etracker();
	$plugin->run();
}
etracker_run();
